title: Authors

Main Contributors of the official Scop3P REST API Python client
=================================

This Python package, which provides a Client for Scop3P REST API, has been developed and maintained by:

* __[Pathmanaban Ramasamy](https://orcid.org/0000-0003-4039-5230)__ (CompOmics)

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.
    - Interuniversity Institute of Bioinformatics in Brussels, ULB-VUB, 1050 Brussels, Belgium.
    - Structural Biology Brussels, Vrije Universiteit Brussel, Pleinlaan 2, 1050 Brussels, Belgium.
    - Centre for Structural Biology, VIB, 1050 Brussels, Belgium.
        
* __[Natalia Tichshenko](https://orcid.org/0000-0001-7914-0759)__ (CompOmics)

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.

* __[Adrián Díaz](https://orcid.org/0000-0003-0165-1318)__ (Bio2Byte)

    - Interuniversity Institute of Bioinformatics in Brussels, ULB-VUB, Brussels, Belgium
    - Structural Biology Brussels, Vrije Universiteit Brussel, Brussels, Belgium


Authors of Scop3P publication 
=============================

_"Scop3P: A Comprehensive Resource of Human Phosphosites within Their Full Context"_

* __[Pathmanaban Ramasamy](https://orcid.org/0000-0003-4039-5230)__

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.
    - Interuniversity Institute of Bioinformatics in Brussels, ULB-VUB, 1050 Brussels, Belgium.
    - Structural Biology Brussels, Vrije Universiteit Brussel, Pleinlaan 2, 1050 Brussels, Belgium.
    - Centre for Structural Biology, VIB, 1050 Brussels, Belgium.
    
* __Demet Turan__
    
    -  VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.

* __[Natalia Tichshenko](https://orcid.org/0000-0001-7914-0759)__

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.

* __Niels Hulstaert__
    
    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.
    

* __[Elien Vandermarliere](https://orcid.org/0000-0001-5514-1060)__

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium.
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.

* __[Wim Vranken](https://orcid.org/0000-0001-7470-4324)__

    - Interuniversity Institute of Bioinformatics in Brussels, ULB-VUB, Brussels, Belgium
    - Structural Biology Brussels, Vrije Universiteit Brussel, Brussels, Belgium
    - Centre for Structural Biology, VIB, 1050 Brussels, Belgium.
    
* __[Lennart Martens](https://orcid.org/0000-0003-4277-658X)__

    - VIB-UGent Center for Medical Biotechnology, VIB, Ghent 9000, Belgium
    - Department of Biomolecular Medicine, Faculty of Health Sciences and Medicine, Ghent University, Ghent 9000, Belgium.

More Contributors
=================

The incomplete list of individuals below have provided patches or otherwise
contributed to the project prior to the project being hosted on GitHub. See the
GitHub commit log for a list of recent contributors. We would like to thank
everyone who has contributed to the project in any way.

* and many others who helped by reporting bugs...
